import copy
import json

import requests

from base import BaseDiziCrawler
from pyquery import PyQuery as pq


class DizimekCrawler(BaseDiziCrawler):
    def __init__(self):
        BaseDiziCrawler.__init__(self)

    def generate_episode_page_url(self):
        return "http://188.166.65.249/diziapi/" + self.episode['dizi_url'] + "/season/" + \
               str(self.episode['season']) + "/episode/" + str(self.episode['episode'])

    def after_body_loaded(self, text):
        sources = json.loads(text)
        self.episode['video_links'] = sources['video_links']
        self.episode['subtitle_links'] = sources['subtitle_links']

        self.episode['site'] = 'dizimek'






import copy
import json

import re

import demjson
import requests

from base import BaseDiziCrawler
from pyquery import PyQuery as pq


class SezonlukDiziCrawler(BaseDiziCrawler):
    def __init__(self):
        BaseDiziCrawler.__init__(self)

    def generate_episode_page_url(self):
        return "http://sezonlukdizi.net/" + self.episode['dizi_url'] + "/" + \
               str(self.episode['season']) + "-sezon-" + str(self.episode['episode']) + "-bolum.html"

    def after_body_loaded(self, text):
        page_dom = pq(text)
        player_address = "http:" + page_dom("iframe[height='360']").eq(0).attr("src")

        result = requests.get(player_address, headers=BaseDiziCrawler.headers)

        if result.status_code == 200:
            self.after_sources_loaded(result.text)

        self.episode['site'] = 'sezonlukdizi'

    def after_sources_loaded(self, text):
        videopush = re.compile(r"video\.push\(([^(]*)\);")
        for m in re.finditer(videopush, text):
            match = m.group(1)

            source = json.loads(match)

            if 'p' not in str(source['label']):
                source['label'] = str(source['label']) + 'p'

            if 'http' not in source['file']:
                source['file'] = 'http:' + source['file']

            video_link = {"res": source['label'], "url": source['file']}
            self.episode['video_links'].append(video_link)

        subpush = re.compile(r"altyazi\.push\(([^(]*)\);")
        for m in re.finditer(subpush, text):
            match = m.group(1)

            source = demjson.decode(match)

            if source['label'][0] == 'T':
                source['label'] = 'tr'
            elif source['label'][0] == 'E':
                source['label'] = 'en'

            if 'http' not in source['file']:
                source['file'] = 'http:' + source['file']

            subtitle_link = {"lang": source['label'], "url": source['file'], "kind": "vtt"}
            self.episode['subtitle_links'].append(subtitle_link)

        video = re.compile(r"var video = ([^(]*)\}\];")
        for m in re.finditer(video, text):
            match = m.group(1) + "}]"

            sources = json.loads(match)
            for source in sources:
                if 'p' not in str(source['label']):
                    source['label'] = str(source['label']) + 'p'

                if 'http' not in source['file']:
                    source['file'] = 'http:' + source['file']

                video_link = {"res": source['label'], "url": source['file']}
                self.episode['video_links'].append(video_link)

        sub = re.compile(r"var altyazi = ([^(]*)\}\];")
        for m in re.finditer(sub, text):
            match = m.group(1) + "}]"

            sources = json.loads(match)
            for source in sources:
                if source['label'][0] == 'T':
                    source['label'] = 'tr'
                elif source['label'][0] == 'E':
                    source['label'] = 'en'

                if 'http' not in source['file']:
                    source['file'] = 'http:' + source['file']

                subtitle_link = {"lang": source['label'], "url": source['file'], "kind": "vtt"}
                self.episode['subtitle_links'].append(subtitle_link)





import copy
import json

import re
import requests

from base import BaseDiziCrawler
from pyquery import PyQuery as pq


class DiziayCrawler(BaseDiziCrawler):
    def __init__(self):
        BaseDiziCrawler.__init__(self)

    def generate_episode_page_url(self):
        return "http://diziay.com/izle/" + self.episode['dizi_url'] + "-" + \
               str(self.episode['season']) + "-sezon-" + str(self.episode['episode']) + "-bolum/"

    def after_body_loaded(self, text):
        page_dom = pq(text)
        player_address = page_dom("iframe[height='375']").attr("src")
        ajax_address = player_address.replace("dizi-oynat", "ajax")

        ajax_headers = copy.copy(BaseDiziCrawler.headers)
        ajax_headers['X-Requested-With'] = 'XMLHttpRequest'
        result = requests.get(ajax_address, headers=ajax_headers)

        if result.status_code == 200:
            self.after_sources_loaded(result.text)

        self.episode['site'] = 'diziay'

    def after_sources_loaded(self, text):
        sources = json.loads(text)['success']

        for source in sources:
            video_link = {"res": source['label'], "url": source['src']}
            if "mp4" in source['type']:
                self.episode['video_links'].append(video_link)





import base64
import json
import os
import sys
import argparse
import signal

import subprocess
import pget
import webbrowser

import requests

from vizontele import crawler
from vizontele.crawler import Crawler


def download_callback(downloader):
    percent = ("{0:.1f}")\
        .format(100 * (downloader.total_downloaded / float(downloader.total_length)))
    filled_length = int(80 * downloader.total_downloaded / downloader.total_length)
    bar = '█' * filled_length + '-' * (80 - filled_length)
    sys.stdout.write('\r%s |%s| %s%% %s' % (downloader.readable_speed, bar, percent, ''))
    sys.stdout.flush()
    # Print New Line on Complete
    if downloader.total_downloaded == downloader.total_length:
        sys.stdout.write('\n')


def run(argv):
    parser = argparse.ArgumentParser(description='Vizontele - Watch, Download, Crawl TV Series')
    parser.add_argument('dizi', metavar='Family Guy', help='Name of the TV Show', type=str)
    parser.add_argument('season', metavar='12', help='Season number', type=int)
    parser.add_argument('episode', metavar='15', help='Episode number', type=int)
    parser.add_argument('--site', metavar='dizilab', help='Website to crawl', type=str, default='',
                        choices=crawler.dizisites.keys())
    parser.add_argument('-o', dest="output", metavar='output.json', help='Output file for crawling result', type=str)
    parser.add_argument('--vlc', metavar='/vlc/binary/destination', help='Link VLC executable to play this episode',
                        type=str)
    parser.add_argument('-d', dest="download", help='If given, episode is downloaded with highest quality.',
                        action='store_true', default=False)

    try:
        args = parser.parse_args(argv)
    except:
        return

    c = Crawler(args.site, args.dizi, args.season, args.episode)
    episode = c.get_sources()

    out_text = json.dumps(episode)
    if args.output is not None:
        with open(args.output, 'w') as f:
            f.write(out_text)
    else:
        from pprint import pprint
        pprint(episode)
        print '\n\n'

    if len(episode['video_links']) == 0:
        return

    if args.vlc is not None:
        if args.vlc == 'web':
            webbrowser.open_new_tab(episode['video_links'][-1]['url'])
        else:
            subprocess.call([args.vlc, '-f', episode['video_links'][-1]['url']])

    if args.download:
        dirname = os.path.join(os.getcwd(), episode['dizi_url'], str(episode['season']), str(episode['episode']))

        if not os.path.isdir(dirname):
            os.makedirs(dirname)

        if os.path.isdir(dirname):
            videoname = os.path.join(dirname, 'Video.mp4')
            downloader = pget.Downloader(episode['video_links'][-1]['url'], videoname, 16)
            print("Downloading: %s" % videoname)
            downloader.subscribe(download_callback, 256)
            downloader.start_sync()
            if len(episode['subtitle_links']) > 0:
                for sub in episode['subtitle_links']:
                    subname = os.path.join(dirname, sub['lang'] + '.vtt')
                    downloader = pget.Downloader(sub['url'], subname, 1)
                    print("Downloading: %s" % subname)
                    downloader.subscribe(download_callback, 256)
                    downloader.start_sync()


def main():
    if sys.stdin.isatty():
        run(sys.argv[1:])
    else:
        argv = sys.stdin.read().split(' ')
        run(argv)



import copy
import json

import requests
from furl import furl

from base import BaseDiziCrawler
from pyquery import PyQuery as pq


class DiziboxCrawler(BaseDiziCrawler):
    def __init__(self):
        BaseDiziCrawler.__init__(self)

    def generate_episode_page_url(self):
        return "http://www.dizibox1.com/" + self.episode['dizi_url'] + "-" + \
               str(self.episode['season']) + "-sezon-" + str(self.episode['episode']) + "-bolum-izle"

    def after_body_loaded(self, text):
        ajax_headers = copy.copy(BaseDiziCrawler.headers)
        ajax_headers['X-Requested-With'] = 'XMLHttpRequest'

        page_dom = pq(text)
        player_address = page_dom("iframe[src^='http://play.dizibox.net']").attr("src")
        f = furl(player_address)
        video_id = f.args['v']
        source_url = f.scheme + '://' + f.host + str(f.path) + "?p=GetVideoSources"

        result = requests.post(source_url, headers=ajax_headers, data={"ID": video_id})

        if result.status_code == 200:
            self.after_sources_loaded(result.text)

        self.episode['site'] = 'dizibox'

    def after_sources_loaded(self, text):
        sources = json.loads(text)['VideoSources']

        for source in sources:
            if 'p' not in source['label']:
                source['label'] += 'p'
            video_link = {"res": source['label'], "url": source['file']}
            if source['type'] == "mp4":
                self.episode['video_links'].append(video_link)





import copy
import json

import re
import requests

from base import BaseDiziCrawler
from pyquery import PyQuery as pq


class DizimagCrawler(BaseDiziCrawler):
    def __init__(self):
        BaseDiziCrawler.__init__(self)

    def generate_episode_page_url(self):
        return "http://dizimag2.co/" + self.episode['dizi_url'] + "/" + \
               str(self.episode['season']) + "-sezon-" + str(self.episode['episode']) + "-bolum-izle-dizi.html"

    def after_body_loaded(self, text):
        ajax_headers = copy.copy(BaseDiziCrawler.headers)
        ajax_headers['X-Requested-With'] = 'XMLHttpRequest'
        ajax_headers['Referer'] = self.generate_episode_page_url()

        page_dom = pq(text)
        kaynak_degis = page_dom(".alterlink").eq(0).attr("onclick")
        kaynak_degis = re.search(r"kaynakdegis\('([0-9]+)'", kaynak_degis).group(1)

        result = requests.post("http://dizimag2.co/service/partikule", headers=ajax_headers, data={"id": kaynak_degis})

        if result.status_code == 200:
            self.after_sources_loaded(result.text)

        self.episode['site'] = 'dizimag'

    def after_sources_loaded(self, text):
        sources = json.loads(text)

        for key in sources.keys():
            if "videokalite" in key:
                if 'p' not in sources[key]:
                    sources[key] += 'p'
                video_link = {"res": sources[key], "url": sources[key.replace("videokalite", "videolink")]}
                self.episode['video_links'].append(video_link)

            elif "altyazitype" in key:
                sub_link = {"lang": "tr",
                            "url": "http://www.dizimag1.co/dizi/" + sources[key] +
                                   "/" + self.episode['dizi_url'] + "/tr-" +
                                   self.episode['season'] + "-" + self.episode['episode'] + ".vtt",
                            "kind": "srt"}
                self.episode['subtitle_links'].append(sub_link)

                sub_link = {"lang": "en",
                            "url": "http://www.dizimag1.co/dizi/" + sources[key] +
                                   "/" + self.episode['dizi_url'] + "/en-" +
                                   self.episode['season'] + "-" + self.episode['episode'] + ".vtt",
                            "kind": "srt"}
                self.episode['subtitle_links'].append(sub_link)



import json
import re

from base import BaseDiziCrawler


class DizistCrawler(BaseDiziCrawler):
    def __init__(self):
        BaseDiziCrawler.__init__(self)

    def generate_episode_page_url(self):
        return "http://www.dizist1.com/izle/" + self.episode['dizi_url'] + "-" + \
               str(self.episode['season']) + "-sezon-" + str(self.episode['episode']) + "-bolum"

    def after_body_loaded(self, text):
        m = re.search(r"var sources = JSON.parse\(\'(.*?)\'\);", text)
        match = m.group(1)

        print match

        sources = json.loads(match)
        for source in sources:
            if 'p' not in source['label']:
                source['label'] += 'p'
            video_link = {"res": source['label'], "url": source['file']}
            if source['type'] == "mp4":
                self.episode['video_links'].append(video_link)

        self.episode['site'] = 'dizist'







import requests
import vizontele


class BaseDiziCrawler:
    headers = dict()
    headers["Accept"] = "text/html,application/xhtml+xml," + \
                        "application/xml;q=0.9,image/webp,*/*;q=0.8"
    headers["Accept-Encoding"] = "gzip] = deflate] = sdch"
    headers["Accept-Language"] = "en-US,en;q=0.8"
    headers["Connection"] = "keep-alive"
    headers["Upgrade-Insecure-Requests"] = "1"
    headers["User-Agent"] = "Mozilla/5.0 (X11; Linux x86_64) " + \
                            "AppleWebKit/537.36 (KHTML, like Gecko) " + \
                            "Ubuntu Chromium/51.0.2704.79 " + \
                            "Chrome/51.0.2704.79 " + \
                            "Safari/537.36"

    def __init__(self):
        self.episode = None

    def get_sources(self, episode):
        self.episode = episode
        self.episode['video_links'] = list()
        self.episode['subtitle_links'] = list()

        result = requests.get(self.generate_episode_page_url())
        if result.status_code == 200:
            try:
                self.after_body_loaded(result.text)
                self.episode['video_links'] = vizontele.sort_video_links(self.episode['video_links'])
            except:
                pass

        return self.episode

    def generate_episode_page_url(self):
        # Must be implemented by child class
        pass

    def after_body_loaded(self, text):
        # Must be implemented by child class
        pass



import copy
import json

import re
import requests

from base import BaseDiziCrawler
from pyquery import PyQuery as pq


class DizipubCrawler(BaseDiziCrawler):
    def __init__(self):
        BaseDiziCrawler.__init__(self)

    def generate_episode_page_url(self):
        return "http://dizipub.com/" + self.episode['dizi_url'] + "-" + \
               str(self.episode['season']) + "-sezon-" + str(self.episode['episode']) + "-bolum"

    def after_body_loaded(self, text):
        ajax_headers = copy.copy(BaseDiziCrawler.headers)
        ajax_headers['X-Requested-With'] = 'XMLHttpRequest'
        ajax_headers['Referer'] = self.generate_episode_page_url()

        page_dom = pq(text)
        player_address = page_dom('.object-wrapper').eq(0).find('iframe').attr('src')

        result = requests.get(player_address, headers=BaseDiziCrawler.headers)

        if result.status_code == 200:
            self.after_sources_loaded(result.text)

        self.episode['site'] = 'dizipub'

    def after_sources_loaded(self, text):
        m = re.search(r'sources: (.*?) ],', text)
        match = m.group(1) + "]"

        sources = json.loads(match)

        for source in sources:
            if 'p' not in source['label']:
                source['label'] += 'p'
            video_link = {"res": source['label'], "url": source['file']}
            if source['type'] == "mp4":
                self.episode['video_links'].append(video_link)


